goverge
========
[![codecov](https://codecov.io/gh/Workiva/goverge/branch/master/graph/badge.svg)](https://codecov.io/gh/Workiva/goverge)
goverge is a golang multi package coverage reporting tool.

Install
-------
    pip install goverge

Testing
-------
    pip install -r requirements_dev.txt
    nosetests

Contributing
-------
    Code: 
        Must be flake8 compliant -- pip install -r requirements_dev.txt to install flake8
        Must be unit tested
        Must have clear doc strings
    
